### Name: soil
### Title: Soil data of North Bavaria, Germany
### Aliases: soil
### Keywords: datasets

### ** Examples


################################################################
##                                                            ##
##         a geostatistical analysis that demonstrates        ##
##         features of the package `RandomFields'             ##
##                                                            ##
##        *** THIS EXAMPLE IS NOT RUN AUTOMATICALLY ***       ##
##        ***      SINCE IT IS TIME CONSUMING       ***       ##
##                                                            ##
################################################################

## Not run: 
##D 
##D data(soil)
##D names(soil)
##D pts <- soil[,c(1,2)]
##D d <- soil$moisture
##D 
##D ## define some graphical parameters first
##D close.screen(close.screen())
##D maxbin <- max(dist(pts)) / 2
##D (zlim <- range(d))
##D cn <- 100
##D colour <- rainbow(cn)
##D par(bg="white",cex=1, cex.lab=1.4, cex.axis=1.4, mar=c(4.3,4.3,0.8,0.8))
##D lu.x <- min(soil$x)
##D lu.y <- max(soil$y)
##D y <- x <- seq(min(soil$x), max(soil$x), l=121) 
##D 
##D ## ... and a certain appearance of the legend
##D my.legend <- function(lu.x, lu.y, zlim, col, cex=1) {
##D   ## uses already the legend code of R-1.3.0
##D   cn <- length(col)
##D   filler <- vector("character", length=(cn-3)/2)
##D   legend(lu.x, lu.y, y.i=0.03, x.i=0.1, 
##D          legend=c(format(zlim[2], dig=2), filler,
##D          format(mean(zlim), dig=2), filler,
##D          format(zlim[1], dig=2)),
##D          lty=1, col=col[length(col):1],cex=cex)
##D }
##D 
##D ## plot the data first
##D plot(pts, col=colour[1+99*((d-min(d))/diff(zlim))], pch=16,
##D      xlab="x [cm]", ylab="y [cm]")
##D my.legend(lu.x, lu.y, zlim=zlim, col=colour, cex=1.4)
##D 
##D ## empirical variogram
##D ev <- EmpiricalVariogram(pts, data=d, grid=FALSE,
##D                          bin=c(-1,seq(0,maxbin,l=30)))
##D 
##D ## show all models,
##D by.eye <- ShowModels(x=x, y=y, emp=ev, col=colour, zlim=zlim,
##D                      Mean=mean(d))
##D 
##D ## fit parameters of the whittlematern model by MLE
##D mle <- fitvario(x=pts, data=d, model="whittle", par=rep(NA,5))
##D 
##D ## plot the fitted model and the empirical variogram
##D plot(ev$c, ev$emp.var, ylim=c(0,11), ylab="variogram", xlab="lag")
##D gx <- seq(0.001, max(ev$c), l=100)
##D if(!is.null(by.eye)) lines(gx, Variogram(gx, model=by.eye)) 
##D lines(gx, Variogram(gx, model=mle$mle), col=2)
##D lines(gx, Variogram(gx, model=mle$lsq), col=3)
##D lines(gx, Variogram(gx, model=mle$nlsq), col=4)
##D lines(gx, Variogram(gx, model=mle$slsq), col=5)
##D legend(120, 4, c("empirical", "by eye", "MLE", "lsq", "sqrt(n) lsq",
##D                "sd^-0.5 lsq"),
##D        lty=c(-1, rep(1, 5)), pch=c(1, rep(-1, 5)),
##D        col=c(1, 1, 2, 3, 4, 5), cex=1.4)
##D 
##D ## map of expected values
##D k <- Kriging("O", x=x, y=y, grid=TRUE, model=mle$mle, given=pts, data=d)
##D image(x, y, k, col=colour, zlim=zlim, xlab="x [cm]", ylab="y [cm]")
##D par(bg="white")
##D my.legend(lu.x, lu.y, zlim=zlim, col=colour, cex=1.4)
##D 
##D ## what is the probability that at no point of the
##D ## grid given by x and y the moisture is greater than 24 percent?
##D cs <- CondSimu("O", x=x, y=y, grid=TRUE, model=mle$mle, given=pts,
##D                data=d, n=10) # better n=100 or n=1000
##D image(x, y, cs[,,1], col=colour, zlim=zlim, xlab="x [cm]",
##D       ylab="y [cm]")
##D my.legend(lu.x, lu.y, zlim=zlim, col=colour, cex=1.4)
##D mean(apply(cs<=24, 3, all)) ## about 40 percent ...
##D 
## End(Not run)




